#-*- coding: iso-8859-1 -*-

import sys
import os
import json
import requests
from pprint import pprint

'''
This script downloads the json file from an incom project and all media files
'''


def main():
  # first the script asks for the project number
  projectNumber = raw_input('Please enter project number: ')
  # some paths get stored in variables for better file handling
  # the name of the project directory
  projectDirectory = 'Project' + projectNumber
  # the name of the original json file, wich we will only read after we received it
  originalJsonPath = os.path.join(projectDirectory, projectNumber + '.json')
  # the name of the copy of the json file, wich we will modify and use later in Adobe Indesign
  copyJsonPath = os.path.join(projectDirectory, projectNumber + 'InDesign.json')
  # this is the path to the directory where we will download all files to
  filesPath = os.path.join(projectDirectory, 'files')
  # make a new directory for the project if it isn't already existing
  if not os.path.exists(projectDirectory):
    os.makedirs(projectDirectory)
    os.makedirs(filesPath)
    # open a file for storing the json data
    jsonDL = open(originalJsonPath, 'w')
    # writing the file with the returning data from the getJSON function
    jsonDL.write(getJSON(projectNumber))
    # always close the file
    jsonDL.close()
  
  # calling the paseJson function with paths to the original json file, the copy of the json file, and the directory to all the downloaded files
  parseJson(originalJsonPath, copyJsonPath, filesPath)

# this function downloads the content of the json file and retuns it to the main function
# here we use the request library http://docs.python-requests.org/en/latest/
def getJSON(projectNumber):
  # we build the url to the projects' json file with teh number from the prompt
  url = 'https://fhp.incom.org/projekt/'+ projectNumber +'.json'
  # http request
  r = requests.get(url)
  # return the content
  return r.content

# we work through the json file so discover downloadable files
def parseJson(originalJsonPath, copyJsonPath, filesPath):
  # open the original json file in read only mode
  jsonFile = open(originalJsonPath, 'r')
  # get the json data stored in a variable
  jsonData = json.load(jsonFile)
  # always close a file
  jsonFile.close()
  # get the title image
  jsonData['response']['image']['path'] = getDownload(jsonData['response']['image']['preview'],jsonData['response']['image']['filename'], filesPath)
  # looping through the files section
  for aFile in jsonData['response']['files']:
    # adding the path attribute to the file object and getting the value back from the 
    # getDownload function
    aFile['path'] = getDownload(aFile['preview'], aFile['filename'], filesPath)

  # looping through the posts section
  for aPost in jsonData['response']['posts']:
    # if a post has media there might be something to download
    if aPost['media']:
      # looping throug media
      for aMedium in aPost['media']:
        # only if the medium has the type file we can download it
        if aMedium['type'] == u'file':
          # adding the path attribute to the medium object and getting the value back from the 
          # getDownload function
          aMedium['path'] =  getDownload(aMedium['preview'], aMedium['filename'], filesPath)

  # we create and open a copy of the json file where we put the modified content in
  jsonFileCopy = open(copyJsonPath, 'w')
  jsonFileCopy.write(json.dumps(jsonData))
  # always close the file
  jsonFileCopy.close()
  return

# this function downloads the files using the request library
def getDownload(fileURL, fileName, filePath):
  r = requests.get(fileURL)
  # create a path where you want to save the file
  downloadPath= os.path.join(filePath, fileName)
  downloadFile = open(downloadPath, 'w')
  downloadFile.write(r.content)
  downloadFile.close()
  # return a path relative to the InDesign json
  return os.path.join('files', fileName)


if __name__ == '__main__':
  main()